Stan Math Library: stan/math/prim/mat/fun/trace_gen_quad_form.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
trace_gen_quad_form.hpp File Reference
`#include <boost/utility/enable_if.hpp>`
`#include <boost/type_traits.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/err/check_multiplicable.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int RD, int CD, int RA, int CA, int RB, int CB>
double | stan::math::trace_gen_quad_form (const Eigen::Matrix< double, RD, CD > &D, const Eigen::Matrix< double, RA, CA > &A, const Eigen::Matrix< double, RB, CB > &B)
| Compute trace(D B^T A B). More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.